@@ -2,7 +2,7 @@
 
 package Git::Hooks::CheckCommit;
 # ABSTRACT: Git::Hooks plugin to enforce commit policies
-$Git::Hooks::CheckCommit::VERSION = '2.7.0';
+$Git::Hooks::CheckCommit::VERSION = '2.7.1';
 use 5.010;
 use utf8;
 use strict;
@@ -368,6 +368,10 @@ sub check_pre_commit {
 
     _setup_config($git);
 
+    my $current_branch = $git->get_current_branch();
+
+    return 1 unless $git->is_reference_enabled($current_branch);
+
     # Grok author and committer information from git's environment variables, if
     # they're defined. Sometimes they aren't...
 
@@ -396,6 +400,10 @@ sub check_post_commit {
 
     _setup_config($git);
 
+    my $current_branch = $git->get_current_branch();
+
+    return 1 unless $git->is_reference_enabled($current_branch);
+
     my $commit = $git->get_sha1('HEAD');
 
     return signature_errors($git, $commit);
@@ -412,6 +420,7 @@ sub check_affected_refs {
     my $errors = 0;
 
     foreach my $ref ($git->get_affected_refs()) {
+        next unless $git->is_reference_enabled($ref);
         $errors += check_ref($git, $ref);
     }
 
@@ -428,6 +437,15 @@ sub check_patchset {
     my $sha1   = $opts->{'--commit'};
     my $commit = $git->get_commit($sha1);
 
+    # The --branch argument contains the branch short-name if it's in the
+    # refs/heads/ namespace. But we need to always use the branch long-name,
+    # so we change it here.
+    my $branch = $opts->{'--branch'};
+    $branch = "refs/heads/$branch"
+        unless $branch =~ m:^refs/:;
+
+    return 1 unless $git->is_reference_enabled($branch);
+
     return commit_errors($git, $commit) == 0;
 }
 
@@ -458,7 +476,7 @@ Git::Hooks::CheckCommit - Git::Hooks plugin to enforce commit policies
 
 =head1 VERSION
 
-version 2.7.0
+version 2.7.1
 
 =head1 SYNOPSIS
 
@@ -559,6 +577,10 @@ Git::Hooks::CheckCommit - Git::Hooks plugin to enforce commit policies
 
 The plugin is configured by the following git options.
 
+It can be disabled for specific references via the C<githooks.ref> and
+C<githooks.noref> options about which you can read in the L<Git::Hooks>
+documentation.
+
 =head2 githooks.checkcommit.name [!]REGEXP
 
 This multi-valued option impose restrictions on the valid author and
