@@ -2,7 +2,7 @@
 
 package Git::Hooks::CheckFile;
 # ABSTRACT: Git::Hooks plugin for checking files
-$Git::Hooks::CheckFile::VERSION = '2.7.0';
+$Git::Hooks::CheckFile::VERSION = '2.7.1';
 use 5.010;
 use utf8;
 use strict;
@@ -345,6 +345,7 @@ sub check_affected_refs {
     my $errors = 0;
 
     foreach my $ref ($git->get_affected_refs()) {
+        next unless $git->is_reference_enabled($ref);
         my ($old_commit, $new_commit) = $git->get_affected_ref_range($ref);
         $errors += check_new_files($git, $new_commit, $git->filter_files_in_range('AM', $old_commit, $new_commit));
         $errors += deny_case_conflicts($git, $new_commit, sub { $git->filter_files_in_range('ACR', $old_commit, $new_commit) });
@@ -359,6 +360,10 @@ sub check_commit {
 
     _setup_config($git);
 
+    my $current_branch = $git->get_current_branch();
+
+    return 1 unless $git->is_reference_enabled($current_branch);
+
     my $errors = 0;
 
     $errors += check_new_files($git, ':0', $git->filter_files_in_index('AM'));
@@ -375,6 +380,15 @@ sub check_patchset {
 
     return 1 if $git->im_admin();
 
+    # The --branch argument contains the branch short-name if it's in the
+    # refs/heads/ namespace. But we need to always use the branch long-name,
+    # so we change it here.
+    my $branch = $opts->{'--branch'};
+    $branch = "refs/heads/$branch"
+        unless $branch =~ m:^refs/:;
+
+    return 1 unless $git->is_reference_enabled($branch);
+
     my $errors = 0;
 
     $errors += check_new_files($git, $opts->{'--commit'}, $git->filter_files_in_commit('AM', $opts->{'--commit'}));
@@ -409,7 +423,7 @@ Git::Hooks::CheckFile - Git::Hooks plugin for checking files
 
 =head1 VERSION
 
-version 2.7.0
+version 2.7.1
 
 =head1 SYNOPSIS
 
@@ -516,6 +530,10 @@ CheckFile - Git::Hooks plugin for checking files
 
 The plugin is configured by the following git options.
 
+It can be disabled for specific references via the C<githooks.ref> and
+C<githooks.noref> options about which you can read in the L<Git::Hooks>
+documentation.
+
 =head2 githooks.checkfile.name PATTERN COMMAND
 
 This directive tells which COMMAND should be used to check files matching
