@@ -2,7 +2,7 @@
 
 package Git::Hooks::CheckLog;
 # ABSTRACT: Git::Hooks plugin to enforce commit log policies
-$Git::Hooks::CheckLog::VERSION = '2.7.0';
+$Git::Hooks::CheckLog::VERSION = '2.7.1';
 use 5.010;
 use utf8;
 use strict;
@@ -311,6 +311,9 @@ sub check_message_file {
     _setup_config($git);
 
     my $current_branch = $git->get_current_branch();
+
+    return 1 unless $git->is_reference_enabled($current_branch);
+
     if (my @ref = $git->get_config($CFG => 'ref')) {
         return 1 unless $git->is_ref_enabled($current_branch, @ref);
     }
@@ -360,6 +363,7 @@ sub check_affected_refs {
     my $errors = 0;
 
     foreach my $ref ($git->get_affected_refs()) {
+        next unless $git->is_reference_enabled($ref);
         check_ref($git, $ref)
             or ++$errors;
     }
@@ -384,6 +388,8 @@ sub check_patchset {
     $branch = "refs/heads/$branch"
         unless $branch =~ m:^refs/:;
 
+    return 1 unless $git->is_reference_enabled($branch);
+
     if (my @ref = $git->get_config($CFG => 'ref')) {
         return 1 unless $git->is_ref_enabled($branch, @ref);
     }
@@ -419,7 +425,7 @@ Git::Hooks::CheckLog - Git::Hooks plugin to enforce commit log policies
 
 =head1 VERSION
 
-version 2.7.0
+version 2.7.1
 
 =head1 SYNOPSIS
 
@@ -521,8 +527,14 @@ Git::Hooks::CheckLog - Git::Hooks plugin to enforce commit log policies
 
 The plugin is configured by the following git options.
 
+It can be disabled for specific references via the C<githooks.ref> and
+C<githooks.noref> options about which you can read in the L<Git::Hooks>
+documentation.
+
 =head2 githooks.checklog.ref REFSPEC
 
+This option is DEPRECATED. Please, use the C<githooks.ref> option instead.
+
 By default, the message of every commit is checked. If you want to
 have them checked only for some refs (usually some branch under
 refs/heads/), you may specify them with one or more instances of this
@@ -535,6 +547,8 @@ caret (C<^>), which is kept as part of the regexp
 
 =head2 githooks.checklog.noref REFSPEC
 
+This option is DEPRECATED. Please, use the C<githooks.noref> option instead.
+
 By default, the message of every commit is checked. If you want to exclude
 some refs (usually some branch under refs/heads/), you may specify them with
 one or more instances of this option.
