@@ -2,7 +2,7 @@
 
 package Git::Hooks::Notify;
 # ABSTRACT: Git::Hooks plugin to notify users via email
-$Git::Hooks::Notify::VERSION = '2.7.0';
+$Git::Hooks::Notify::VERSION = '2.7.1';
 use 5.010;
 use utf8;
 use strict;
@@ -225,6 +225,7 @@ sub notify_affected_refs {
     my $errors = 0;
 
     foreach my $ref (@refs) {
+        next unless $git->is_reference_enabled($ref);
         my ($old_commit, $new_commit) = $git->get_affected_ref_range($ref);
         foreach my $rule (@rules) {
             my @commits = $git->get_commits($old_commit, $new_commit, \@options, $rule->{paths});
@@ -269,7 +270,7 @@ Git::Hooks::Notify - Git::Hooks plugin to notify users via email
 
 =head1 VERSION
 
-version 2.7.0
+version 2.7.1
 
 =head1 SYNOPSIS
 
@@ -389,6 +390,10 @@ Notify - Git::Hooks plugin to notify users via email
 
 The plugin is configured by the following git options.
 
+It can be disabled for specific references via the C<githooks.ref> and
+C<githooks.noref> options about which you can read in the L<Git::Hooks>
+documentation.
+
 =head2 githooks.notify.rule RECIPIENTS [-- PATHSPECS]
 
 The B<rule> directive adds a notification rule specifying which RECIPIENTS
